<?php 
/**
 * File containing DefensiveAttack class.
 *
 * @package 	DefensiveAttack
 * @version 	1.0.0
 * @copyright 	Copyright (C)2006 TheLordOfWeb. All rights reserved.
 * @license 	http://www.gnu.org/copyleft/gpl.html GNU Public License
 * @filesource
 */

/**
 * 	LICENSE
 * 	This program is free software; you can redistribute it and/or
 * 	modify it under the terms of the GNU General Public License (GPL)
 * 	as published by the Free Software Foundation; either version 2
 * 	of the License, or (at your option) any later version.
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *	To read the license please visit http://www.gnu.org/copyleft/gpl.html
 *	----------------------------------------------------------------------
 *	Original Author of file:
 *	Purpose of file:
 *	----------------------------------------------------------------------
 * 	Tested with IE 6, Netscape 7, Opera 9, Firefox 2
 * 	This is free software. Use at your own risk.
 */

/**
 * DefensiveAttack class for php 5.x
 *
 * 
 * @package 	DefensiveAttack
 * @author 		TheLordOfWeb	<http://thelordofweb.atspace.com/>
 * @version 	1.0.0
 * @copyright 	Copyright (C)2006 TheLordOfWeb. All rights reserved.
 * @license 	http://www.gnu.org/copyleft/gpl.html GNU Public License
 * @example		example_1.php
 * @example		example_2.php
 * @example		example_3.php
 * @example		example_4.php
 * @example		example_5.php
 */
class DefensiveAttack  {
    
    /**
     * My host name
     *
     * @access protected
     * @var string
     */
    protected   $mMyHostName   =   '';
    
    /**
	 * My IP address
	 *
	 * @access protected
	 * @var string
	 */
	protected  $mMyIpAddress   =   '127.0.0.1';
	
	/**
	 * Outside IP address
	 *
	 * @access protected
	 * @var string
	 */
	protected  $mIpAddress     =   '127.0.0.1';
	
	/**
	 * Referer
	 *
	 * @access protected
	 * @var string
	 */
	protected  $mReferer       =   '';
	
	/**
	 * DefensiveAttack constructor
	 *
	 * @access public
	 * @param string hostname
	 */
	public function __construct($myHostName  =  null) {

	    //Set my host name
	    $this->mMyHostName     =   (!isset($myHostName)) ? htmlentities($_SERVER['HTTP_HOST'],ENT_QUOTES,'utf-8') : $myHostName;
	    
	    //Set outside IP address
	    $this->mIpAddress      = $this->SetRealIp();
	    
	    //Set referer
	    $this->mReferer        = $this->SetReferer();
	    
	}
	
	/**
	 * Set real outside IP address
	 *
	 * @access protected
	 * @return string
	 */
	protected function &SetRealIp(){
	    
	    $ip    =   '';
	    
	    if (isset($_SERVER['HTTP_X_FORWARDED_FOR']) AND !empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
	        foreach (explode(',',$_SERVER['HTTP_X_FORWARDED_FOR']) as $values) {
	            $ip    .=   long2ip(ip2long($values)) . ' ; ';
	        }
	    
	    } else {
	        $ip = long2ip(ip2long($_SERVER['REMOTE_ADDR']));
	    }
	    
	    return $ip;
	    
	}
	
	/**
	 * Get IP outside address
	 *
	 * @access public
	 * @return string
	 */
	public function &GetIpAddress() {
	    
	    return $this->mIpAddress;
	    
	}
	
	/**
	 * Set my IP address
	 *
	 * @access public
	 * @param string $ip
	 */
	public function SetMyIpAddress($ip) {
	    
	    $this->mMyIpAddress = long2ip(ip2long($ip));
	}
	
	/**
	 * Compare my IP address with outside IP address
	 *
	 * @access public
	 * @return bool 
	 */
	public function IsIpIdentity() {
	    
	    return (strcmp($this->mIpAddress,$this->mMyIpAddress) == 0) ? true : false;
	    
	}
		
	/**
	 * Get host name
	 *
	 * @access public
	 * @return string
	 */
	public function GetHostName() {
	    
         return gethostbyaddr($this->mIpAddress); 

	}

	/**
	 * Looking for proxy using
	 *
	 * @access public
	 * @return bool
	 */
	public function IsUseProxy() {
	     
	    return (isset($_SERVER['HTTP_X_FORWARDED_FOR']) AND !empty($_SERVER['HTTP_X_FORWARDED_FOR'])) ? true : false;
	    
	}
	
	
	/**
	 * Set ban cookie
	 *
	 * @access public
	 * @param string $path
	 * @param string $cookieName
	 */
	public function SetSmartCookieBan($path = "/",$cookieName="uid_cookie_ban_ban") {
	    
	    setcookie($cookieName,md5(rand()),time() + 86400 * 365,$path,$this->mMyHostName);
	    
	}
	
	/**
	 * Delete ban cookie
	 *
	 * @access public
	 * @param string $path
	 * @param string $cookieName
	 */
	public function DelSmartCookieBan($path = "/",$cookieName="uid_cookie_ban_ban") {
	    
	    setcookie($cookieName,"",time() - 3600,$path,$this->mMyHostName);
	    
	}

	/**
	 * Check Ban cookie
	 *
	 * @access public
	 * @param  string $cookieName
	 * @return bool
	 */
	public function IsSetSmartCookieBan($cookieName="uid_cookie_ban_ban") {
	    
	    return (isset($_COOKIE[$cookieName]) AND !empty($_COOKIE[$cookieName])) ? true : false;
	    
	}
	
	/**
	 * Set referer
	 * 
	 * @access protected
	 * @return string
	 */
	protected function &SetReferer() {
	    
	    //Initialize variable
	    $referer   =   '';
	    
	    if (isset($_SERVER['HTTP_REFERER']) AND !empty($_SERVER['HTTP_REFERER'])) {

	        //Initialize variable
	        $url       =   array();

	        //Parse referer url
	        $url       =   parse_url($_SERVER['HTTP_REFERER']);
            
	        $referer   =   htmlentities($url['host'],ENT_QUOTES,'utf-8');
	        unset($url);
	    }
	    
	    return $referer;
	}
	
	/**
	 * Get referer
	 *
	 * @access public
	 * @return string
	 */
	public function &GetReferer() {
	    
	    return $this->mReferer;
	    
	}
	
	/**
	 * Check referer for my url address
	 *
	 * @access public
	 * @return bool
	 */
	public function CheckReferer() {
	    
	    return (strcmp($this->mMyHostName,$this->mReferer) == 0) ? true : false;
	    
	}
	
	/**
	 * Get input data
	 *
	 * @access public
	 * @return string
	 */
	public function GetInputData() {
	    
	    return htmlentities($_SERVER['QUERY_STRING'],ENT_QUOTES,'utf-8');
	    
	}
	
	/**
	 * Get cookie data
	 *
	 * @access public
	 * @return reference to array
	 */
	public function &GetCookieData() {
	    
	    //Initialize cookie data
	    $cd        =   '';
	    
	    foreach ($_COOKIE as $k => $v ) {
	        $cd    .=   "{$k}={$v},";
	    }
	    
	    $cd    =   htmlentities($cd,ENT_QUOTES,'utf-8');
	    
	    return $cd;
	    
	}
	
	/**
	 * DefensiveAttack destructor
	 * 
	 * @access public
	 */
	public function __destruct() {
	    
	}
	
}

?>